@@ -21,7 +21,7 @@ print "ok 1\n";
 %test_names = (1 => "use Net::Ping::External qw(ping)",
 	       2 => "ping(host => '127.0.0.1')",
 	       3 => "ping(host => '127.0.0.1', timeout => 5)",
-	       4 => "ping(host => 'some.non.existent.host')",
+	       4 => "ping(host => 'some.non.existent.host.')",
 	       5 => "ping(host => '127.0.0.1', count => 10)",
 	       6 => "ping(host => '127.0.0.1', size => 32)"
 	      );
@@ -51,14 +51,25 @@ else {
   push @failed, 3;
 }
 
-eval { $ret = ping(host => 'some.non.existent.host') };
-if (!$@ && !$ret) {
-  print "ok 4\n";
-  push @passed, 4;
+sub inexistent_domain_do_not_resolve {
+  use Socket;
+  return 1 unless inet_aton('some.non.existent.host.');
+  return 0;
 }
-else {
-  print "not ok 4\n";
-  push @failed, 4;
+
+if (inexistent_domain_do_not_resolve()) {
+  eval { $ret = ping(host => 'some.non.existent.host.') };
+  if (!$@ && !$ret) {
+    print "ok 4\n";
+    push @passed, 4;
+  }
+  else {
+    print "not ok 4\n";
+    push @failed, 4;
+  }
+} else {
+  push @passed, 4;
+  print "ok 4 #skipped\n";
 }
 
 eval { $ret = ping(host => '127.0.0.1', count => 2) };
@@ -102,21 +113,28 @@ if (@failed) {
 
 my @output = `$^X -v`;
 my $a='';
-$a.= "\nOperating system according to perl: ", $^O, "\n";
+$a.= "\nOperating system according to perl: ".$^O."\n";
 $a.= "Operating system according to `uname -a` (if available):\n";
 $a.= `uname -a`;
 $a.= "Perl version: ";
 $a.= @output[1..1];
 $a.= "Ping help: ";
-$a.= ($^O eq 'Netbsd'?Net::Ping::External::_locate_ping_netbsd():`ping`);
+my $ping=($^O eq 'Netbsd'?Net::Ping::External::_locate_ping_netbsd():'ping');
+$a.= `$ping 2>&1`;
 $a.="\n";
+if (@failed and $failed[0]==5 and lc($^O) eq 'linux') {
+ $a.="-\nping -c 1 some.non.existent.host\n";
+ $a.=`ping -c 1 some.non.existent.host`;
+ $a.="\n-\n";
+}
 open A,'>NPE.out';
 print A $a;
+close A;
 print $a;
 print "-------------------------------------------------\n";
 print "If any of the above tests failed, please e-mail the bits between the dashed\n";
-print "lines or content of NPE.out to alexchorny AT gmail.com This will help me in fixing this\n";
-print "code for maximum portability to your platform. Thanks!\n";
+print "lines or content of 'NPE.out' to alexchorny AT gmail.com This will help me in\n";
+print "fixing this code for maximum portability to your platform. Thanks!\n";
 
 print "\nTests: ".(@failed?"fail":"ok")."\n";
 exit (@failed?1:0);
